@@ -13,7 +13,9 @@ if __name__ == '__main__':
     params = dict()
 
     form = {
-        "text": "你好"
+        "title": "汽车",
+        "text": "例如会让部件磨损大，使得寿命降低，而且还带来动力降低，油耗越来越高，抖动大等。以前一箱油能跑380公里的，如今却只能跑到350了，无疑也增加了开车成本。",
+        "max_len": 5
     }
 
     resp = nlp_service.text_summarization(form)
